@@ -10,10 +10,6 @@
 
 #include "kiotesthelper.h" // createTestFile etc.
 
-#ifdef Q_OS_UNIX
-#include <signal.h> // kill
-#endif
-
 #include <QStandardPaths>
 #include <QTemporaryDir>
 #include <QTest>
@@ -190,6 +186,35 @@ void CommandLauncherJobTest::startProcessWithSpacesInExecutablePath()
     QTRY_COMPARE(KProcessRunner::instanceCount(), 0);
 }
 
+void CommandLauncherJobTest::startProcessWithEnvironmentVariables()
+{
+    // Given an env var and a command that uses it
+    QProcessEnvironment env;
+    env.insert("MYVAR", "myvalue");
+#ifdef Q_OS_WIN
+    const QString command = "echo myvar=%MYVAR% > destfile";
+#else
+    const QString command = "echo myvar=$MYVAR > destfile";
+#endif
+    QTemporaryDir tempDir;
+    const QString srcDir = tempDir.path();
+    const QString srcFile = srcDir + "/srcfile";
+    createSrcFile(srcFile);
+
+    // When running a CommandLauncherJob
+    KIO::CommandLauncherJob *job = new KIO::CommandLauncherJob(command, this);
+    job->setWorkingDirectory(srcDir);
+    job->setProcessEnvironment(env);
+    QVERIFY(job->exec());
+
+    // Then the env var was visible
+    QFile destFile(srcDir + "/destfile");
+    QTRY_VERIFY(QFileInfo(destFile).size() > 0);
+    QVERIFY(destFile.open(QIODevice::ReadOnly));
+    const QByteArray data = destFile.readAll().trimmed();
+    QCOMPARE(data, "myvar=myvalue");
+}
+
 void CommandLauncherJobTest::doesNotFailOnNonExistingExecutable()
 {
     // Given a command that uses an executable that doesn't exist
@@ -201,6 +226,9 @@ void CommandLauncherJobTest::doesNotFailOnNonExistingExecutable()
 
     // Then it doesn't actually fail. QProcess is starting /bin/sh, which works...
     QVERIFY(job->exec());
+
+    // Wait for KProcessRunner to be deleted
+    QTRY_COMPARE(KProcessRunner::instanceCount(), 0);
 }
 
 void CommandLauncherJobTest::shouldDoNothingOnEmptyCommand()
@@ -211,4 +239,9 @@ void CommandLauncherJobTest::shouldDoNothingOnEmptyCommand()
     // THEN it should do nothing
     // at least not crash (old bug 186036)
     QVERIFY(job->exec());
+
+    // Wait for KProcessRunner to be deleted
+    QTRY_COMPARE(KProcessRunner::instanceCount(), 0);
 }
+
+#include "moc_commandlauncherjobtest.cpp"
