@@ -15,6 +15,7 @@
 #include <kio/simplejob.h>
 #include <kprotocolinfo.h>
 
+#include <KDirNotify>
 #include <KDirWatch>
 
 #include <QDebug>
@@ -47,7 +48,7 @@ void KDirListerTest::initTestCase()
 
     // No message dialogs
     KIO::setDefaultJobUiDelegateExtension(nullptr);
-    KIO::setDefaultJobUiDelegateFactoryV2(nullptr);
+    KIO::setDefaultJobUiDelegateFactory(nullptr);
 
     m_exitCount = 1;
 
@@ -113,9 +114,6 @@ void KDirListerTest::testOpenUrl()
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 1);
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
-#endif
     QCOMPARE(m_dirLister.spyClearDir.count(), 0);
 
     QCOMPARE(m_dirLister.spyRedirection.count(), 0);
@@ -131,9 +129,6 @@ void KDirListerTest::testOpenUrl()
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 1);
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
-#endif
     QCOMPARE(m_dirLister.spyClearDir.count(), 0);
 
     QCOMPARE(m_dirLister.spyRedirection.count(), 0);
@@ -186,9 +181,6 @@ void KDirListerTest::testOpenUrlFromCache()
         QCOMPARE(secondDirLister.spyCanceledQUrl.count(), 0);
         QCOMPARE(secondDirLister.spyClear.count(), 1);
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-        QCOMPARE(secondDirLister.spyClearQUrl.count(), 0);
-#endif
         QCOMPARE(secondDirLister.spyClearDir.count(), 0);
 
         QCOMPARE(m_items.count(), 0);
@@ -203,9 +195,6 @@ void KDirListerTest::testOpenUrlFromCache()
         QCOMPARE(secondDirLister.spyCanceledQUrl.count(), 0);
         QCOMPARE(secondDirLister.spyClear.count(), 1);
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-        QCOMPARE(secondDirLister.spyClearQUrl.count(), 0);
-#endif
         QCOMPARE(secondDirLister.spyClearDir.count(), 0);
 
         QCOMPARE(m_items.count(), 4);
@@ -236,9 +225,6 @@ void KDirListerTest::testNewItem()
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 0);
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
-#endif
     QCOMPARE(m_dirLister.spyClearDir.count(), 0);
 
     const QUrl itemUrl = QUrl::fromLocalFile(path + fileName);
@@ -279,9 +265,6 @@ void KDirListerTest::testNewItems()
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 0);
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
-#endif
     QCOMPARE(m_dirLister.spyClearDir.count(), 0);
 
     const QUrl itemUrl = QUrl::fromLocalFile(path + fileName);
@@ -293,6 +276,8 @@ void KDirListerTest::testNewItems()
 
 void KDirListerTest::benchFindByUrl()
 {
+    // We don't want to run benchmarks as part of the normal tests. This test depends on things being set up, which makes moving it to it's own file hard
+    QSKIP("Skipped by default");
     // The time used should be in the order of O(100*log2(100))
     const QString path = tempPath();
     QBENCHMARK {
@@ -329,9 +314,6 @@ void KDirListerTest::testNewItemByCopy()
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 0);
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
-#endif
     QCOMPARE(m_dirLister.spyClearDir.count(), 0);
 
     // Give some time to KDirWatch
@@ -485,9 +467,6 @@ void KDirListerTest::testRefreshItems()
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 0);
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
-#endif
     QCOMPARE(m_dirLister.spyClearDir.count(), 0);
 
     QCOMPARE(m_refreshedItems.count(), 1);
@@ -538,9 +517,6 @@ void KDirListerTest::testRefreshRootItem()
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 0);
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
-#endif
     QCOMPARE(m_dirLister.spyClearDir.count(), 0);
 
     QCOMPARE(m_refreshedItems.count(), 1);
@@ -702,7 +678,7 @@ void KDirListerTest::testRenameAndOverwrite() // has to be run after testRenameI
 
     // Check that itemsDeleted was emitted -- preferably BEFORE refreshItems,
     // but we can't easily check that with QSignalSpy...
-    QCOMPARE(m_dirLister.spyItemsDeleted.count(), 1);
+    QTRY_COMPARE(m_dirLister.spyItemsDeleted.count(), 1);
 
     QCOMPARE(m_refreshedItems.count(), 1);
     QPair<KFileItem, KFileItem> entry = m_refreshedItems.first();
@@ -747,9 +723,6 @@ void KDirListerTest::testConcurrentListing()
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 1);
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
-#endif
     QCOMPARE(m_dirLister.spyClearDir.count(), 0);
 
     QCOMPARE(m_items.count(), 0);
@@ -761,9 +734,6 @@ void KDirListerTest::testConcurrentListing()
     QCOMPARE(dirLister2.spyCanceledQUrl.count(), 0);
     QCOMPARE(dirLister2.spyClear.count(), 1);
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    QCOMPARE(dirLister2.spyClearQUrl.count(), 0);
-#endif
     QCOMPARE(dirLister2.spyClearDir.count(), 0);
 
     QCOMPARE(m_items2.count(), 0);
@@ -780,9 +750,6 @@ void KDirListerTest::testConcurrentListing()
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 1);
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
-#endif
     QCOMPARE(m_dirLister.spyClearDir.count(), 0);
 
     QCOMPARE(m_items.count(), 3);
@@ -794,9 +761,6 @@ void KDirListerTest::testConcurrentListing()
     QCOMPARE(dirLister2.spyCanceledQUrl.count(), 0);
     QCOMPARE(dirLister2.spyClear.count(), 1);
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    QCOMPARE(dirLister2.spyClearQUrl.count(), 0);
-#endif
     QCOMPARE(dirLister2.spyClearDir.count(), 0);
 
     QCOMPARE(m_items2.count(), origItemCount);
@@ -847,9 +811,6 @@ void KDirListerTest::testConcurrentHoldingListing()
     QCOMPARE(dirLister2.spyCanceledQUrl.count(), 0);
     QCOMPARE(dirLister2.spyClear.count(), 1);
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    QCOMPARE(dirLister2.spyClearQUrl.count(), 0);
-#endif
     QCOMPARE(dirLister2.spyClearDir.count(), 0);
 
     QCOMPARE(m_items2.count(), origItemCount);
@@ -861,9 +822,6 @@ void KDirListerTest::testConcurrentHoldingListing()
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 1);
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
-#endif
     QCOMPARE(m_dirLister.spyClearDir.count(), 0);
 
     QVERIFY(dirLister2.isFinished());
@@ -901,9 +859,6 @@ void KDirListerTest::testConcurrentListingAndStop()
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 1);
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
-#endif
     QCOMPARE(m_dirLister.spyClearDir.count(), 0);
 
     QCOMPARE(m_items.count(), 0);
@@ -915,9 +870,6 @@ void KDirListerTest::testConcurrentListingAndStop()
     QCOMPARE(dirLister2.spyCanceledQUrl.count(), 0);
     QCOMPARE(dirLister2.spyClear.count(), 1);
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    QCOMPARE(dirLister2.spyClearQUrl.count(), 0);
-#endif
     QCOMPARE(dirLister2.spyClearDir.count(), 0);
 
     QCOMPARE(m_items2.count(), 0);
@@ -933,9 +885,6 @@ void KDirListerTest::testConcurrentListingAndStop()
     QCOMPARE(dirLister2.spyCanceledQUrl.count(), 1);
     QCOMPARE(dirLister2.spyClear.count(), 1);
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    QCOMPARE(dirLister2.spyClearQUrl.count(), 0);
-#endif
     QCOMPARE(dirLister2.spyClearDir.count(), 0);
 
     QCOMPARE(m_items2.count(), 0);
@@ -953,9 +902,6 @@ void KDirListerTest::testConcurrentListingAndStop()
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 1);
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
-#endif
     QCOMPARE(m_dirLister.spyClearDir.count(), 0);
 
     disconnect(&m_dirLister, nullptr, this, nullptr);
@@ -1006,9 +952,6 @@ void KDirListerTest::testOpenUrlTwice()
     QCOMPARE(secondDirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(secondDirLister.spyClear.count(), 2);
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    QCOMPARE(secondDirLister.spyClearQUrl.count(), 0);
-#endif
     QCOMPARE(secondDirLister.spyClearDir.count(), 0);
 
     if (origItemCount) { // 0 if running this test separately
@@ -1048,9 +991,6 @@ void KDirListerTest::testOpenUrlTwiceWithKeep()
     QCOMPARE(secondDirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(secondDirLister.spyClear.count(), 1);
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    QCOMPARE(secondDirLister.spyClearQUrl.count(), 1);
-#endif
     QCOMPARE(secondDirLister.spyClearDir.count(), 1);
 
     QCOMPARE(m_items.count(), 0);
@@ -1077,9 +1017,6 @@ void KDirListerTest::testOpenAndStop()
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 1);
     QCOMPARE(m_dirLister.spyClear.count(), 1);
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
-#endif
     QCOMPARE(m_dirLister.spyClearDir.count(), 0);
 
     QCOMPARE(m_items.count(), 0); // we had time to stop before the job even started
@@ -1163,7 +1100,7 @@ void KDirListerTest::testRenameCurrentDir() // #294445
     const QString newPath = tempPath() + "newsubdir-2";
     QVERIFY(QDir().rename(path, newPath));
     org::kde::KDirNotify::emitFileRenamed(QUrl::fromLocalFile(path), QUrl::fromLocalFile(newPath));
-    QSignalSpy spyRedirection(&secondDirLister, qOverload<const QUrl &, const QUrl &>(&KCoreDirLister::redirection));
+    QSignalSpy spyRedirection(&secondDirLister, &KCoreDirLister::redirection);
     QVERIFY(spyRedirection.wait(1000));
 
     // Check that the URL of the root item got updated
@@ -1201,13 +1138,9 @@ void KDirListerTest::testRenameCurrentDirOpenUrl()
 
     // Connect the redirection to openURL, so that on a rename the new location is opened.
     // This matches usage in gwenview, and crashes
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 80)
-    connect(&m_dirLister, qOverload<const QUrl &>(&KCoreDirLister::redirection), this, &KDirListerTest::slotOpenUrlOnRename);
-#else
-    connect(&m_dirLister, qOverload<const QUrl &, const QUrl &>(&KCoreDirLister::redirection), this, [this](const QUrl &, const QUrl &newUrl) {
+    connect(&m_dirLister, &KCoreDirLister::redirection, this, [this](const QUrl &, const QUrl &newUrl) {
         slotOpenUrlOnRename(newUrl);
     });
-#endif
 
     QTRY_VERIFY(m_dirLister.isFinished());
     disconnect(&m_dirLister, nullptr, this, nullptr);
@@ -1234,9 +1167,6 @@ void KDirListerTest::testRedirection()
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QCOMPARE(m_dirLister.spyClear.count(), 1);
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
-#endif
     QCOMPARE(m_dirLister.spyClearDir.count(), 0);
 
     QCOMPARE(m_dirLister.spyRedirection.count(), 0);
@@ -1252,9 +1182,6 @@ void KDirListerTest::testRedirection()
     QCOMPARE(m_dirLister.spyCanceledQUrl.count(), 0);
     QTRY_COMPARE(m_dirLister.spyClear.count(), 2); // redirection cleared a second time (just in case...)
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
-#endif
     QCOMPARE(m_dirLister.spyClearDir.count(), 0);
 
     QTRY_COMPARE(m_dirLister.spyRedirection.count(), 1);
@@ -1516,13 +1443,9 @@ void KDirListerTest::testRenameDirectory() // #401552
     QString currDir = dirW;
     KIO::SimpleJob *job = nullptr;
     // Connect the redirection to openURL, so that on a rename the new location is opened.
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 80)
-    connect(&m_dirLister, qOverload<const QUrl &>(&KCoreDirLister::redirection), this, &KDirListerTest::slotOpenUrlOnRename);
-#else
-    connect(&m_dirLister, qOverload<const QUrl &, const QUrl &>(&KCoreDirLister::redirection), this, [this](const QUrl &, const QUrl &newUrl) {
+    connect(&m_dirLister, &KCoreDirLister::redirection, this, [this](const QUrl &, const QUrl &newUrl) {
         slotOpenUrlOnRename(newUrl);
     });
-#endif
 
     for (int i = 0; i < dirs.size(); i++) {
         // Wait for the listener to get all files
@@ -1638,9 +1561,6 @@ void KDirListerTest::testDeleteCurrentDir()
     QVERIFY(ok);
     QTRY_COMPARE(m_dirLister.spyClear.count(), 1);
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    QCOMPARE(m_dirLister.spyClearQUrl.count(), 0);
-#endif
     QCOMPARE(m_dirLister.spyClearDir.count(), 0);
 
     QList<QUrl> deletedUrls;
