@@ -20,11 +20,9 @@ enum Command {
     CMD_HOST = '0', // 48
     CMD_CONNECT = '1', // 49
     CMD_DISCONNECT = '2', // 50
-    CMD_SLAVE_STATUS = '3', // 51
-    CMD_SLAVE_CONNECT = '4', // 52
-    CMD_SLAVE_HOLD = '5', // 53
+    CMD_WORKER_STATUS = '3', // 51
     CMD_NONE = 'A', // 65
-    CMD_TESTDIR = 'B', // 66   TODO KF6 REMOVE
+    // Unused: 'B', // 66
     CMD_GET = 'C', // 67
     CMD_PUT = 'D', // 68
     CMD_STAT = 'E', // 69
@@ -40,11 +38,11 @@ enum Command {
     CMD_REPARSECONFIGURATION = 'O', // 79
     CMD_META_DATA = 'P', // 80
     CMD_SYMLINK = 'Q', // 81
-    CMD_SUBURL = 'R', // 82  Inform the worker about the URL it is streaming on. TODO KF6 REMOVE
+    // Unused: 'R', // 82
     CMD_MESSAGEBOXANSWER = 'S', // 83
     CMD_RESUMEANSWER = 'T', // 84
     CMD_CONFIG = 'U', // 85
-    CMD_MULTI_GET = 'V', // 86
+    // unused 'V', // 86
     CMD_SETLINKDEST = 'W', // 87
     CMD_OPEN = 'X', // 88
     CMD_CHOWN = 'Y', // 89
@@ -55,6 +53,7 @@ enum Command {
     CMD_HOST_INFO = 94,
     CMD_FILESYSTEMFREESPACE = 95,
     CMD_TRUNCATE = 96,
+    CMD_SSLERRORANSWER,
     // Add new ones here once a release is done, to avoid breaking binary compatibility.
     // Note that protocol-specific commands shouldn't be added here, but should use special.
 };
