@@ -13,26 +13,22 @@
 
 #include <QObject>
 #include <QUrl>
+#include <memory>
 
 namespace KIO
 {
 class ConnectionServerPrivate;
 class Connection;
 
-/**
- * @private
- * @internal
- *
+/*
  * This class provides a way to obtaining KIO::Connection connections.
- * Used by klauncher.
- * Do not use outside KIO and klauncher!
  */
-class KIOCORE_EXPORT ConnectionServer : public QObject
+class ConnectionServer : public QObject
 {
     Q_OBJECT
 public:
     explicit ConnectionServer(QObject *parent = nullptr);
-    ~ConnectionServer();
+    ~ConnectionServer() override;
 
     /**
      * Sets this connection to listen mode. Use address() to obtain the
@@ -57,7 +53,7 @@ Q_SIGNALS:
 
 private:
     friend class ConnectionServerPrivate;
-    ConnectionServerPrivate *const d;
+    std::unique_ptr<ConnectionServerPrivate> const d;
 };
 
 } // namespace KIO
