@@ -81,21 +81,6 @@ KIOCORE_EXPORT unsigned int calculateRemainingSeconds(KIO::filesize_t totalSize,
  */
 KIOCORE_EXPORT QString convertSeconds(unsigned int seconds);
 
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(3, 4)
-/**
- * Calculates remaining time from total size, processed size and speed.
- *
- * @param  totalSize      total size in bytes
- * @param  processedSize  processed size in bytes
- * @param  speed          speed in bytes per second
- * @return calculated remaining time
- * @deprecated Since 3.4, use calculateRemainingSeconds() instead, as QTime is limited to 23:59:59
- */
-KIOCORE_EXPORT
-KIOCORE_DEPRECATED_VERSION(3, 4, "Use KIO::calculateRemainingSeconds(KIO::filesize_t, KIO::filesize_t, KIO::filesize_t")
-QTime calculateRemaining(KIO::filesize_t totalSize, KIO::filesize_t processedSize, KIO::filesize_t speed);
-#endif
-
 /**
  * Helper for showing information about a set of files and directories
  * @param items the number of items (= @p files + @p dirs + number of symlinks :)
@@ -124,20 +109,6 @@ KIOCORE_EXPORT QString encodeFileName(const QString &str);
  */
 KIOCORE_EXPORT QString decodeFileName(const QString &str);
 
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 61)
-/**
- * Given a directory path and a filename (which usually exists already),
- * this function returns a suggested name for a file that doesn't exist
- * in that directory. The existence is only checked for local urls though.
- * The suggested file name is of the form "foo 1", "foo 2" etc.
- * @since 5.0
- * @deprecated since 5.61, use KFileUtils::suggestName() from KCoreAddons
- */
-KIOCORE_EXPORT
-KIOCORE_DEPRECATED_VERSION(5, 61, "Use KFileUtils::suggestName(const QUrl &, const QString &) from KCoreAddons")
-QString suggestName(const QUrl &baseURL, const QString &oldName);
-#endif
-
 /**
  * Error codes that can be emitted by KIO.
  */
@@ -163,91 +134,31 @@ enum Error {
     ERR_CYCLIC_LINK = KJob::UserDefinedError + 19,
     ERR_USER_CANCELED = KJob::KilledJobError,
     ERR_CYCLIC_COPY = KJob::UserDefinedError + 21,
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_CREATE_SOCKET KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_CREATE_SOCKET.") =
-        KJob::UserDefinedError + 22, ///< @deprecated Since 5.0, use ERR_CANNOT_CREATE_SOCKET
-#endif
     ERR_CANNOT_CREATE_SOCKET = KJob::UserDefinedError + 22,
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_CONNECT KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_CONNECT.") =
-        KJob::UserDefinedError + 23, ///< @deprecated Since 5.0, use ERR_CANNOT_CONNECT
-#endif
     ERR_CANNOT_CONNECT = KJob::UserDefinedError + 23,
     ERR_CONNECTION_BROKEN = KJob::UserDefinedError + 24,
     ERR_NOT_FILTER_PROTOCOL = KJob::UserDefinedError + 25,
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_MOUNT KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_MOUNT.") =
-        KJob::UserDefinedError + 26, ///< @deprecated Since 5.0, use ERR_CANNOT_MOUNT
-#endif
     ERR_CANNOT_MOUNT = KJob::UserDefinedError + 26,
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_UNMOUNT KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_UNMOUNT.") =
-        KJob::UserDefinedError + 27, ///< @deprecated Since 5.0, use ERR_CANNOT_UNMOUNT
-#endif
     ERR_CANNOT_UNMOUNT = KJob::UserDefinedError + 27,
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_READ KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_READ.") =
-        KJob::UserDefinedError + 28, ///< @deprecated Since 5.0, use ERR_CANNOT_READ
-#endif
     ERR_CANNOT_READ = KJob::UserDefinedError + 28,
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_WRITE KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_WRITE.") =
-        KJob::UserDefinedError + 29, ///< @deprecated Since 5.0, use ERR_CANNOT_WRITE
-#endif
     ERR_CANNOT_WRITE = KJob::UserDefinedError + 29,
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_BIND KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_BIND.") =
-        KJob::UserDefinedError + 30, ///< @deprecated Since 5.0, use ERR_CANNOT_BIND
-#endif
     ERR_CANNOT_BIND = KJob::UserDefinedError + 30,
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_LISTEN KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_LISTEN.") =
-        KJob::UserDefinedError + 31, ///< @deprecated Since 5.0, use ERR_CANNOT_LISTEN
-#endif
     ERR_CANNOT_LISTEN = KJob::UserDefinedError + 31,
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_ACCEPT KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_ACCEPT.") =
-        KJob::UserDefinedError + 32, ///< @deprecated Since 5.0, use ERR_CANNOT_ACCEPT
-#endif
     ERR_CANNOT_ACCEPT = KJob::UserDefinedError + 32,
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_LOGIN KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_LOGIN.") =
-        KJob::UserDefinedError + 33, ///< @deprecated Since 5.0, use ERR_CANNOT_LOGIN
-#endif
     ERR_CANNOT_LOGIN = KJob::UserDefinedError + 33,
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_STAT KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_STAT.") =
-        KJob::UserDefinedError + 34, ///< @deprecated Since 5.0, use ERR_CANNOT_STAT
-#endif
     ERR_CANNOT_STAT = KJob::UserDefinedError + 34,
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_CLOSEDIR KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_CLOSEDIR.") =
-        KJob::UserDefinedError + 35, ///< @deprecated Since 5.0, use ERR_CANNOT_CLOSEDIR
-#endif
     ERR_CANNOT_CLOSEDIR = KJob::UserDefinedError + 35,
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_MKDIR KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_AUTHENTICATE.") =
-        KJob::UserDefinedError + 37, ///< @deprecated Since 5.0, use ERR_CANNOT_MKDIR
-#endif
     ERR_CANNOT_MKDIR = KJob::UserDefinedError + 37,
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_RMDIR KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_RMDIR.") =
-        KJob::UserDefinedError + 38, ///< @deprecated Since 5.0, use ERR_CANNOT_RMDIR
-#endif
     ERR_CANNOT_RMDIR = KJob::UserDefinedError + 38,
     ERR_CANNOT_RESUME = KJob::UserDefinedError + 39,
     ERR_CANNOT_RENAME = KJob::UserDefinedError + 40,
     ERR_CANNOT_CHMOD = KJob::UserDefinedError + 41,
     ERR_CANNOT_DELETE = KJob::UserDefinedError + 42,
-    // The text argument is the protocol that the dead slave supported.
+    // The text argument is the protocol that the dead worker supported.
     // This means for example: file, ftp, http, ...
-    ERR_SLAVE_DIED = KJob::UserDefinedError + 43,
+    ERR_WORKER_DIED = KJob::UserDefinedError + 43, ///< @since 5.96
     ERR_OUT_OF_MEMORY = KJob::UserDefinedError + 44,
     ERR_UNKNOWN_PROXY_HOST = KJob::UserDefinedError + 45,
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_AUTHENTICATE KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_AUTHENTICATE.") =
-        KJob::UserDefinedError + 46, ///< @deprecated Since 5.0, use ERR_CANNOT_AUTHENTICATE
-#endif
     ERR_CANNOT_AUTHENTICATE = KJob::UserDefinedError + 46,
     ERR_ABORTED = KJob::UserDefinedError + 47, ///< Action got aborted from application side
     ERR_INTERNAL_SERVER = KJob::UserDefinedError + 48,
@@ -265,20 +176,20 @@ enum Error {
     ERR_NO_CONTENT = KJob::UserDefinedError + 60, ///< Action succeeded but no content will follow.
     ERR_DISK_FULL = KJob::UserDefinedError + 61,
     ERR_IDENTICAL_FILES = KJob::UserDefinedError + 62, ///< src==dest when moving/copying
-    ERR_SLAVE_DEFINED = KJob::UserDefinedError + 63, ///< for slave specified errors that can be
-    ///< rich text.  Email links will be handled
-    ///< by the standard email app and all hrefs
-    ///< will be handled by the standard browser.
-    ///< <a href="exec:/khelpcenter ?" will be
-    ///< forked.
+    /**
+     * For worker specified errors that can be
+     * rich text.  Email links will be handled
+     * by the standard email app and all hrefs
+     * will be handled by the standard browser.
+     * <a href="exec:/khelpcenter ?" will be
+     * forked.
+     * @since 5.96
+     */
+    ERR_WORKER_DEFINED = KJob::UserDefinedError + 63,
     ERR_UPGRADE_REQUIRED = KJob::UserDefinedError + 64, ///< A transport upgrade is required to access this
     ///< object.  For instance, TLS is demanded by
     ///< the server in order to continue.
     ERR_POST_DENIED = KJob::UserDefinedError + 65, ///< Issued when trying to POST data to a certain Ports
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    ERR_COULD_NOT_SEEK KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use ERR_CANNOT_SEEK.") =
-        KJob::UserDefinedError + 66, ///< @deprecated Since 5.0, use ERR_CANNOT_SEEK
-#endif
     // see job.cpp
     ERR_CANNOT_SEEK = KJob::UserDefinedError + 66,
     ERR_CANNOT_SETTIME = KJob::UserDefinedError + 67, ///< Emitted by setModificationTime
@@ -286,19 +197,26 @@ enum Error {
     ERR_POST_NO_SIZE = KJob::UserDefinedError + 69,
     ERR_DROP_ON_ITSELF = KJob::UserDefinedError + 70, ///< from KIO::DropJob, @since 5.6
     ERR_CANNOT_MOVE_INTO_ITSELF = KJob::UserDefinedError + 71, ///< emitted by KIO::move, @since 5.18
-    ERR_PASSWD_SERVER = KJob::UserDefinedError + 72, ///< returned by SlaveBase::openPasswordDialogV2, @since 5.24
-    ERR_CANNOT_CREATE_SLAVE = KJob::UserDefinedError + 73, ///< used by Slave::createSlave, @since 5.30
+    ERR_PASSWD_SERVER = KJob::UserDefinedError + 72, ///< returned by WorkerBase::openPasswordDialog, @since 5.24
+    ERR_CANNOT_CREATE_WORKER = KJob::UserDefinedError + 73, ///< used by Worker::createWorker, @since 5.96
     ERR_FILE_TOO_LARGE_FOR_FAT32 = KJob::UserDefinedError + 74, ///< @since 5.54
-    ERR_OWNER_DIED = KJob::UserDefinedError
-        + 75, ///< Value used between kuiserver and views when the job owner disappears unexpectedly. It should not be emitted by slaves. @since 5.54
-    ERR_PRIVILEGE_NOT_REQUIRED = KJob::UserDefinedError + 76, ///< used by file ioslave, @since 5.60
+    ERR_OWNER_DIED ///< Value used between kuiserver and views when the job owner disappears unexpectedly. It should not be emitted by workers. @since 5.54
+    = KJob::UserDefinedError + 75,
+    ERR_PRIVILEGE_NOT_REQUIRED = KJob::UserDefinedError + 76, ///< used by file ioworker, @since 5.60
     ERR_CANNOT_TRUNCATE = KJob::UserDefinedError + 77, // used by FileJob::truncate, @since 5.66
     /**
      * Indicates failure to create a symlink due to the underlying filesystem (FAT/ExFAT)
      * not supporting them. Used by e.g. CopyJob.
      * @since 5.88
      */
-    ERR_SYMLINKS_NOT_SUPPORTED = KJob::UserDefinedError + 78
+    ERR_SYMLINKS_NOT_SUPPORTED = KJob::UserDefinedError + 78,
+
+    /**
+     * Moving files/dirs to the Trash failed due to size constraints.
+     *
+     * @since 5.100
+     */
+    ERR_TRASH_FILE_TOO_LARGE = KJob::UserDefinedError + 79,
 };
 
 /**
@@ -406,7 +324,6 @@ KIOCORE_EXPORT QString favIconForUrl(const QUrl &url);
  * @param permissions KIO file permissions.
  *
  * @return -1 if @p permissions is -1, otherwise its OR'ed QFile::Permission equivalent.
- * @since 4.12
  */
 KIOCORE_EXPORT QFile::Permissions convertPermissions(int permissions);
 
