@@ -16,8 +16,8 @@
 #include "global.h"
 #include "kiocoredebug.h"
 #include "simplejob.h"
-#include "slave.h"
 #include "transferjob.h"
+#include "worker_p.h"
 #include <KJobTrackerInterface>
 #include <QDataStream>
 #include <QPointer>
@@ -71,7 +71,7 @@ public:
         Rename,
         Symlink,
         Transfer, // put() and get()
-        Other, // if other file operation set message, caption inside the job.
+        Other, // if other file operation set message, title inside the job.
     };
 
     // Maybe we could use the QObject parent/child mechanism instead
@@ -85,13 +85,14 @@ public:
     Job *q_ptr;
     // For privilege operation
     bool m_privilegeExecutionEnabled;
-    QString m_caption, m_message;
+    QString m_title, m_message;
     FileOperationType m_operationType;
 
     QByteArray privilegeOperationData();
     void slotSpeed(KJob *job, unsigned long speed);
 
     static void emitMoving(KIO::Job *, const QUrl &src, const QUrl &dest);
+    static void emitRenaming(KIO::Job *, const QUrl &src, const QUrl &dest);
     static void emitCopying(KIO::Job *, const QUrl &src, const QUrl &dest);
     static void emitCreatingDir(KIO::Job *, const QUrl &dir);
     static void emitDeleting(KIO::Job *, const QUrl &url);
@@ -99,7 +100,6 @@ public:
     static void emitTransferring(KIO::Job *, const QUrl &url);
     static void emitMounting(KIO::Job *, const QString &dev, const QString &point);
     static void emitUnmounting(KIO::Job *, const QString &point);
-    static void setTransient(KIO::Job *, bool transient = true);
 
     Q_DECLARE_PUBLIC(Job)
 };
@@ -114,7 +114,7 @@ public:
      * @param packedArgs the arguments
      */
     SimpleJobPrivate(const QUrl &url, int command, const QByteArray &packedArgs)
-        : m_slave(nullptr)
+        : m_worker(nullptr)
         , m_packedArgs(packedArgs)
         , m_url(url)
         , m_command(command)
@@ -123,17 +123,16 @@ public:
     {
     }
 
-    QPointer<Slave> m_slave;
+    QPointer<Worker> m_worker;
     QByteArray m_packedArgs;
     QUrl m_url;
-    QUrl m_subUrl;
     int m_command;
 
     // for use in KIO::Scheduler
     //
     // There are two kinds of protocol:
     // (1) The protocol of the url
-    // (2) The actual protocol that the io-slave uses.
+    // (2) The actual protocol that the KIO worker uses.
     //
     // These two often match, but not necessarily. Most notably, they don't
     // match when doing ftp via a proxy.
@@ -142,8 +141,8 @@ public:
     // JobData::protocol stores (2) while Job::url().protocol() returns (1).
     // The ProtocolInfoDict is indexed with (2).
     //
-    // We schedule slaves based on (2) but tell the slave about (1) via
-    // Slave::setProtocol().
+    // We schedule workers based on (2) but tell the worker about (1) via
+    // Worker::setProtocol().
     QString m_protocol;
     QStringList m_proxyList;
     int m_schedSerial;
@@ -152,53 +151,53 @@ public:
     void simpleJobInit();
 
     /**
-     * Called on a slave's connected signal.
+     * Called on a worker's connected signal.
      * @see connected()
      */
     void slotConnected();
     /**
-     * Forward signal from the slave.
+     * Forward signal from the worker.
      * @param data_size the processed size in bytes
      * @see processedSize()
      */
     void slotProcessedSize(KIO::filesize_t data_size);
     /**
-     * Forward signal from the slave.
+     * Forward signal from the worker.
      * @param speed the speed in bytes/s
      * @see speed()
      */
     void slotSpeed(unsigned long speed);
     /**
-     * Forward signal from the slave
+     * Forward signal from the worker.
      * Can also be called by the parent job, when it knows the size.
      * @param data_size the total size
      */
     void slotTotalSize(KIO::filesize_t data_size);
 
     /**
-     * Called on a slave's info message.
+     * Called on a worker's info message.
      * @param s the info message
      * @see infoMessage()
      */
-    void _k_slotSlaveInfoMessage(const QString &s);
+    void _k_slotWorkerInfoMessage(const QString &s);
 
     /**
-     * Called when privilegeOperationRequested() is emitted by slave.
+     * Called when privilegeOperationRequested() is emitted by worker.
      */
     void slotPrivilegeOperationRequested();
 
     /**
      * @internal
-     * Called by the scheduler when a slave gets to
+     * Called by the scheduler when a worker gets to
      * work on this job.
      **/
-    virtual void start(KIO::Slave *slave);
+    virtual void start(KIO::Worker *worker);
 
     /**
      * @internal
-     * Called to detach a slave from a job.
+     * Called to detach a worker from a job.
      **/
-    void slaveDone();
+    void workerDone();
 
     /**
      * Called by subclasses to restart the job after a redirection was signalled.
@@ -207,20 +206,6 @@ public:
      */
     void restartAfterRedirection(QUrl *redirectionUrl);
 
-    /**
-     * Request the ui delegate to show a message box.
-     * @internal
-     */
-    int requestMessageBox(int type,
-                          const QString &text,
-                          const QString &caption,
-                          const QString &buttonYes,
-                          const QString &buttonNo,
-                          const QString &iconYes = QString(),
-                          const QString &iconNo = QString(),
-                          const QString &dontAskAgainName = QString(),
-                          const KIO::MetaData &sslMetaData = KIO::MetaData());
-
     Q_DECLARE_PUBLIC(SimpleJob)
 
     static inline SimpleJobPrivate *get(KIO::SimpleJob *job)
@@ -272,7 +257,6 @@ public:
         , staticData(_staticData)
         , m_isMimetypeEmitted(false)
         , m_closedBeforeStart(false)
-        , m_subJob(nullptr)
     {
     }
 
@@ -282,7 +266,6 @@ public:
         , m_errorPage(false)
         , m_isMimetypeEmitted(false)
         , m_closedBeforeStart(false)
-        , m_subJob(nullptr)
         , m_outgoingDataSource(QPointer<QIODevice>(ioDevice))
     {
     }
@@ -295,28 +278,27 @@ public:
     QString m_mimetype;
     bool m_isMimetypeEmitted;
     bool m_closedBeforeStart;
-    TransferJob *m_subJob;
     QPointer<QIODevice> m_outgoingDataSource;
     QMetaObject::Connection m_readChannelFinishedConnection;
 
     /**
-     * Flow control. Suspend data processing from the slave.
+     * Flow control. Suspend data processing from the worker.
      */
     void internalSuspend();
     /**
-     * Flow control. Resume data processing from the slave.
+     * Flow control. Resume data processing from the worker.
      */
     void internalResume();
     /**
      * @internal
-     * Called by the scheduler when a slave gets to
+     * Called by the scheduler when a worker gets to
      * work on this job.
-     * @param slave the slave that works on the job
+     * @param worker the worker that works on the job
      */
-    void start(KIO::Slave *slave) override;
+    void start(KIO::Worker *worker) override;
     /**
      * @internal
-     * Called when the ioslave needs the data to send the server. This slot
+     * Called when the KIO worker needs the data to send the server. This slot
      * is invoked when the data is to be sent is read from a QIODevice rather
      * instead of a QByteArray buffer.
      */
@@ -324,8 +306,6 @@ public:
     void slotIODeviceClosed();
     void slotIODeviceClosedBeforeStart();
     void slotPostRedirection();
-    void slotNeedSubUrlData();
-    void slotSubUrlData(KIO::Job *, const QByteArray &);
 
     Q_DECLARE_PUBLIC(TransferJob)
     static inline TransferJob *newJob(const QUrl &url, int command, const QByteArray &packedArgs, const QByteArray &_staticData, JobFlags flags)
@@ -333,7 +313,7 @@ public:
         TransferJob *job = new TransferJob(*new TransferJobPrivate(url, command, packedArgs, _staticData));
         job->setUiDelegate(KIO::createDefaultJobUiDelegate());
         if (!(flags & HideProgressInfo)) {
-            JobPrivate::setTransient(job);
+            job->setFinishedNotificationHidden();
             KIO::getJobTracker()->registerJob(job);
         }
         if (!(flags & NoPrivilegeExecution)) {
@@ -348,7 +328,7 @@ public:
         TransferJob *job = new TransferJob(*new TransferJobPrivate(url, command, packedArgs, ioDevice));
         job->setUiDelegate(KIO::createDefaultJobUiDelegate());
         if (!(flags & HideProgressInfo)) {
-            JobPrivate::setTransient(job);
+            job->setFinishedNotificationHidden();
             KIO::getJobTracker()->registerJob(job);
         }
         if (!(flags & NoPrivilegeExecution)) {
@@ -362,7 +342,7 @@ public:
 class DirectCopyJobPrivate;
 /**
  * @internal
- * Used for direct copy from or to the local filesystem (i.e.\ SlaveBase::copy())
+ * Used for direct copy from or to the local filesystem (i.e.\ WorkerBase::copy())
  */
 class DirectCopyJob : public SimpleJob
 {
