@@ -111,33 +111,13 @@ public:
      */
     KFileItem(const KIO::UDSEntry &entry, const QUrl &itemOrDirUrl, bool delayedMimeTypes = false, bool urlIsDirectory = false);
 
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    /**
-     * Creates an item representing a file, from all the necessary info for it.
-     * @param mode the file mode (according to stat() (e.g. S_IFDIR...)
-     * Set to KFileItem::Unknown if unknown. For local files, KFileItem will use stat().
-     * @param permissions the access permissions
-     * If you set both the mode and the permissions, you save a ::stat() for
-     * local files.
-     * Set to KFileItem::Unknown if you don't know the mode or the permission.
-     * @param url the file url
-     *
-     * @param delayedMimeTypes specify if the MIME type of the given URL
-     *       should be determined immediately or on demand
-     * @deprecated since 5.0. Most callers gave Unknown for mode and permissions,
-     * so just port to KFileItem(url) and setDelayedMimeTypes(true) if necessary.
-     */
-    KIOCORE_DEPRECATED_VERSION(5, 0, "See API docs")
-    KFileItem(mode_t mode, mode_t permissions, const QUrl &url, bool delayedMimeTypes = false);
-#endif
-
     /**
      * Creates an item representing a file, for which the MIME type is already known.
      * @param url the file url
      * @param mimeType the name of the file's MIME type
      * @param mode the mode (S_IFDIR...)
      */
-    KFileItem(const QUrl &url, const QString &mimeType = QString(), mode_t mode = KFileItem::Unknown); // KF6 TODO: explicit!
+    explicit KFileItem(const QUrl &url, const QString &mimeType = QString(), mode_t mode = KFileItem::Unknown);
 
     /**
      * Creates an item representing a file, with the option of skipping MIME type determination.
@@ -265,6 +245,19 @@ public:
      */
     mode_t mode() const;
 
+    /**
+     * Returns the file's owner's user id.
+     * Available only on supported protocols.
+     * @since 6.0
+     */
+    int userId() const;
+    /**
+     * Returns the file's owner's group id.
+     * Available only on supported protocols.
+     * @since 6.0
+     */
+    int groupId() const;
+
     /**
      * Returns the owner of the file.
      * @return the file's owner
@@ -329,7 +322,6 @@ public:
      * Checks whether the file is a readable local .desktop file,
      * i.e.\ a file whose path can be given to KDesktopFile
      * @return true if the file is a desktop file.
-     * @since 4.1
      */
     bool isDesktopFile() const;
 
@@ -343,13 +335,15 @@ public:
      * Returns the target url of the file, which is the same as url()
      * in cases where the worker doesn't specify UDS_TARGET_URL
      * @return the target url.
-     * @since 4.1
      */
     QUrl targetUrl() const;
 
     /**
      * Returns the local path if isLocalFile() == true or the KIO item has
      * a UDS_LOCAL_PATH atom.
+     *
+     * Treat it as a readonly path to open/list contents, use original url to move/delete files.
+     *
      * @return the item local path, or QString() if not known
      */
     QString localPath() const;
@@ -388,11 +382,6 @@ public:
      */
     Q_INVOKABLE QString timeString(FileTimes which = ModificationTime) const;
 
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(4, 0)
-    KIOCORE_DEPRECATED_VERSION(4, 0, "Use KFileItem::timeString(FileTimes)")
-    QString timeString(unsigned int which) const;
-#endif
-
     /**
      * Returns true if the file is a local file.
      * @return true if the file is local, false otherwise
@@ -478,7 +467,6 @@ public:
      * A comment which can contain anything - even rich text. It will
      * simply be displayed to the user as is.
      *
-     * @since 4.6
      */
     QString comment() const;
 
@@ -489,21 +477,6 @@ public:
      */
     QString getStatusBarInfo() const;
 
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(4, 0)
-    /**
-     * Returns true if files can be dropped over this item.
-     * Contrary to popular belief, not only dirs will return true :)
-     * Executables, .desktop files, will do so as well.
-     * @return true if you can drop files over the item
-     *
-     * @deprecated Since 4.0. This logic is application-dependent, the behavior described above
-     * mostly makes sense for file managers only.
-     * KDirModel has setDropsAllowed for similar (but configurable) logic.
-     */
-    KIOCORE_DEPRECATED_VERSION(4, 0, "See API docs")
-    bool acceptsDrops() const;
-#endif
-
     /**
      * Returns the UDS entry. Used by the tree view to access all details
      * by position.
@@ -514,10 +487,16 @@ public:
     /**
      * Return true if this item is a regular file,
      * false otherwise (directory, link, character/block device, fifo, socket)
-     * @since 4.3
      */
     bool isRegularFile() const;
 
+    /**
+     * Returns the file extension
+     * Similar to QFileInfo::suffix except it takes into account UDS_DISPLAY_NAME and saves a stat call
+     * @since 6.0
+     */
+    QString suffix() const;
+
     /**
      * Somewhat like a comparison operator, but more explicit,
      * and it can detect that two fileitems differ if any property of the file item
@@ -556,14 +535,6 @@ public:
      */
     operator QVariant() const;
 
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(4, 0)
-    /**
-     * @deprecated Since 4.0, simply use '='
-     */
-    KIOCORE_DEPRECATED_VERSION(4, 0, "Use KFileItem::operator=(const KFileItem&)")
-    void assign(const KFileItem &item);
-#endif
-
     /**
      * Tries to return a local URL for this file item if possible.
      * If @p local is not null, it will be set to @c true if the returned url is local,
@@ -579,7 +550,6 @@ public:
      * }
      * @endcode
      *
-     * @since 4.6
      */
     QUrl mostLocalUrl(bool *local = nullptr) const;
 
@@ -608,29 +578,31 @@ public:
      */
     MostLocalUrlResult isMostLocalUrl() const;
 
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    /**
-     * @deprecated since 5.0 add '&' in front of your boolean argument
-     */
-    KIOCORE_DEPRECATED_VERSION(5, 0, "Use KFileItem::mostLocalUrl(bool *)")
-    QUrl mostLocalUrl(bool &local) const
-    {
-        return mostLocalUrl(&local);
-    }
-#endif
-
     /**
      * Return true if default-constructed
      */
     bool isNull() const;
 
+    /**
+     * returns whether the KFileItem exists on-disk
+     * Call only after initialization (i.e `KIO::stat` or `refresh()` for local files)
+     * @since 6.0
+     */
+    bool exists() const;
+
+    /**
+     * Return true if the file has executable permission
+     * @since 6.0
+     */
+    bool isExecutable() const;
+
 private:
     QSharedDataPointer<KFileItemPrivate> d;
 
     /**
      * Hides the file.
      */
-    void setHidden();
+    KIOCORE_NO_EXPORT void setHidden();
 
 private:
     KIOCORE_EXPORT friend QDataStream &operator<<(QDataStream &s, const KFileItem &a);
@@ -641,7 +613,7 @@ private:
 };
 
 Q_DECLARE_METATYPE(KFileItem)
-Q_DECLARE_TYPEINFO(KFileItem, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(KFileItem, Q_RELOCATABLE_TYPE);
 
 inline uint qHash(const KFileItem &item)
 {
