@@ -10,7 +10,7 @@
 
 #include "job_p.h"
 #include "scheduler.h"
-#include "slave.h"
+#include "worker_p.h"
 #include <KProtocolInfo>
 #include <QTimer>
 #include <kurlauthorized.h>
@@ -36,11 +36,11 @@ public:
 
     /**
      * @internal
-     * Called by the scheduler when a @p slave gets to
+     * Called by the scheduler when a @p worker gets to
      * work on this job.
-     * @param slave the slave that starts working on this job
+     * @param worker the worker that starts working on this job
      */
-    void start(Slave *slave) override;
+    void start(Worker *worker) override;
 
     Q_DECLARE_PUBLIC(StatJob)
 
@@ -67,13 +67,6 @@ StatJob::~StatJob()
 {
 }
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 0)
-void StatJob::setSide(bool source)
-{
-    d_func()->m_bSource = source;
-}
-#endif
-
 void StatJob::setSide(StatSide side)
 {
     d_func()->m_bSource = side == SourceSide;
@@ -84,34 +77,6 @@ void StatJob::setDetails(KIO::StatDetails details)
     d_func()->m_details = details;
 }
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 69)
-void StatJob::setDetails(short int details)
-{
-    // for backward compatibility
-    d_func()->m_details = detailsToStatDetails(details);
-}
-
-void StatJob::setDetails(KIO::StatDetail detail)
-{
-    d_func()->m_details = detail;
-}
-
-KIO::StatDetails KIO::detailsToStatDetails(int details)
-{
-    KIO::StatDetails detailsFlag = KIO::StatBasic;
-    if (details > 0) {
-        detailsFlag |= KIO::StatUser | KIO::StatTime;
-    }
-    if (details > 1) {
-        detailsFlag |= KIO::StatResolveSymlink | KIO::StatAcl;
-    }
-    if (details > 2) {
-        detailsFlag |= KIO::StatInode;
-    }
-    return detailsFlag;
-}
-#endif
-
 const UDSEntry &StatJob::statResult() const
 {
     return d_func()->m_statResult;
@@ -143,20 +108,20 @@ QUrl StatJob::mostLocalUrl() const
     return QUrl::fromLocalFile(path);
 }
 
-void StatJobPrivate::start(Slave *slave)
+void StatJobPrivate::start(Worker *worker)
 {
     Q_Q(StatJob);
     m_outgoingMetaData.insert(QStringLiteral("statSide"), m_bSource ? QStringLiteral("source") : QStringLiteral("dest"));
-    m_outgoingMetaData.insert(QStringLiteral("statDetails"), QString::number(m_details));
+    m_outgoingMetaData.insert(QStringLiteral("details"), QString::number(m_details));
 
-    q->connect(slave, &KIO::SlaveInterface::statEntry, q, [this](const KIO::UDSEntry &entry) {
+    q->connect(worker, &KIO::WorkerInterface::statEntry, q, [this](const KIO::UDSEntry &entry) {
         slotStatEntry(entry);
     });
-    q->connect(slave, &KIO::SlaveInterface::redirection, q, [this](const QUrl &url) {
+    q->connect(worker, &KIO::WorkerInterface::redirection, q, [this](const QUrl &url) {
         slotRedirection(url);
     });
 
-    SimpleJobPrivate::start(slave);
+    SimpleJobPrivate::start(worker);
 }
 
 void StatJobPrivate::slotStatEntry(const KIO::UDSEntry &entry)
@@ -165,7 +130,7 @@ void StatJobPrivate::slotStatEntry(const KIO::UDSEntry &entry)
     m_statResult = entry;
 }
 
-// Slave got a redirection request
+// Worker got a redirection request
 void StatJobPrivate::slotRedirection(const QUrl &url)
 {
     Q_Q(StatJob);
@@ -201,23 +166,10 @@ void StatJob::slotFinished()
         }
     }
 
-    // Return slave to the scheduler
+    // Return worker to the scheduler
     SimpleJob::slotFinished();
 }
 
-void StatJob::slotMetaData(const KIO::MetaData &_metaData)
-{
-    Q_D(StatJob);
-    SimpleJob::slotMetaData(_metaData);
-    storeSSLSessionFromJob(d->m_redirectionURL);
-}
-
-StatJob *KIO::stat(const QUrl &url, JobFlags flags)
-{
-    // Assume sideIsSource. Gets are more common than puts.
-    return statDetails(url, StatJob::SourceSide, KIO::StatDefaultDetails, flags);
-}
-
 static bool isUrlValid(const QUrl &url)
 {
     if (!url.isValid()) {
@@ -240,46 +192,34 @@ static bool isUrlValid(const QUrl &url)
 
 StatJob *KIO::mostLocalUrl(const QUrl &url, JobFlags flags)
 {
-    StatJob *job = statDetails(url, StatJob::SourceSide, KIO::StatDefaultDetails, flags);
+    StatJob *job = stat(url, StatJob::SourceSide, KIO::StatDefaultDetails, flags);
     if (!isUrlValid(url)) {
         QTimer::singleShot(0, job, &StatJob::slotFinished);
-        Scheduler::cancelJob(job); // deletes the slave if not 0
+        Scheduler::cancelJob(job); // deletes the worker if not 0
     }
     return job;
 }
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 0)
-StatJob *KIO::stat(const QUrl &url, bool sideIsSource, short int details, JobFlags flags)
+StatJob *KIO::stat(const QUrl &url, JobFlags flags)
+{
+    // Assume SourceSide. Gets are more common than puts.
+    return stat(url, StatJob::SourceSide, KIO::StatDefaultDetails, flags);
+}
+
+StatJob *KIO::stat(const QUrl &url, KIO::StatJob::StatSide side, KIO::StatDetails details, JobFlags flags)
 {
     // qCDebug(KIO_CORE) << "stat" << url;
     KIO_ARGS << url;
     StatJob *job = StatJobPrivate::newJob(url, CMD_STAT, packedArgs, flags);
-    job->setSide(sideIsSource ? StatJob::SourceSide : StatJob::DestinationSide);
+    job->setSide(side);
     job->setDetails(details);
     return job;
 }
-#endif
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 240)
 StatJob *KIO::statDetails(const QUrl &url, KIO::StatJob::StatSide side, KIO::StatDetails details, JobFlags flags)
 {
-    // TODO KF6: rename to stat
-    // qCDebug(KIO_CORE) << "stat" << url;
-    KIO_ARGS << url;
-    StatJob *job = StatJobPrivate::newJob(url, CMD_STAT, packedArgs, flags);
-    job->setSide(side);
-    job->setDetails(details);
-    return job;
-}
-
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 69)
-StatJob *KIO::stat(const QUrl &url, KIO::StatJob::StatSide side, short int details, JobFlags flags)
-{
-    // qCDebug(KIO_CORE) << "stat" << url;
-    KIO_ARGS << url;
-    StatJob *job = StatJobPrivate::newJob(url, CMD_STAT, packedArgs, flags);
-    job->setSide(side);
-    job->setDetails(details);
-    return job;
+    return stat(url, side, details, flags);
 }
 #endif
 
