@@ -19,12 +19,13 @@
 #include "kiofilewidgets_export.h"
 #include <QWidget>
 
+#include <KFileFilter>
+
 #include <memory>
 
 class QUrl;
 class QPushButton;
 class KActionCollection;
-class KToolBar;
 class KFileWidgetPrivate;
 class KUrlComboBox;
 class KFileFilterCombo;
@@ -135,23 +136,6 @@ public:
      */
     void setUrl(const QUrl &url, bool clearforward = true);
 
-#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(5, 33)
-    /**
-     * Sets the file to preselect to @p pathOrUrl
-     *
-     * This method handles absolute paths (on Unix, but probably not correctly on Windows)
-     * and absolute URLs as strings (but for those you should use setSelectedUrl instead).
-     *
-     * This method does not work with relative paths (filenames)
-     * (it would misinterpret a ':' or a '#' in the filename).
-     *
-     * @deprecated since 5.33, use setSelectedUrl instead, after ensuring that
-     * construct the QUrl correctly (e.g. use fromLocalFile for local paths).
-     */
-    KIOFILEWIDGETS_DEPRECATED_VERSION(5, 33, "Use KFileWidget::setSelectedUrl(const QUrl &)")
-    void setSelection(const QString &pathOrUrl);
-#endif
-
     /**
      * Sets the URL to preselect to @p url
      *
@@ -219,40 +203,18 @@ public:
     bool keepsLocation() const;
 
     /**
-     * Sets the filter to be used to @p filter.
+     * Set the filters to be used.
      *
-     * You can set more
-     * filters for the user to select separated by '\n'. Every
-     * filter entry is defined through namefilter|text to display.
-     * If no | is found in the expression, just the namefilter is
-     * shown. Examples:
+     * Each item of the list corresponds to a selectable filter.
      *
-     * \code
-     * kfile->setFilter("*.cpp|C++ Source Files\n*.h|Header files");
-     * kfile->setFilter("*.cpp");
-     * kfile->setFilter("*.cpp|Sources (*.cpp)");
-     * kfile->setFilter("*.cpp|" + i18n("Sources (*.cpp)"));
-     * kfile->setFilter("*.cpp *.cc *.C|C++ Source Files\n*.h *.H|Header files");
-     * \endcode
+     * Only one filter is active at a time.
      *
-     * Note: The text to display is not parsed in any way. So, if you
-     * want to show the suffix to select by a specific filter, you must
-     * repeat it.
+     * @param activeFilter the initially active filter
      *
-     * If the filter contains an unescaped '/', a MIME type filter is assumed.
-     * If you would like a '/' visible in your filter it can be escaped with
-     * a '\'. You can specify multiple MIME types like this (separated with
-     * space):
+     * @since 6.0
      *
-     * \code
-     * kfile->setFilter( "image/png text/html text/plain" );
-     * kfile->setFilter( "*.cue|CUE\\/BIN Files (*.cue)" );
-     * \endcode
-     *
-     * @see filterChanged
-     * @see setMimeFilter
      */
-    void setFilter(const QString &filter);
+    void setFilters(const QList<KFileFilter> &filters, const KFileFilter &activeFilter = KFileFilter());
 
     /**
      * Returns the current filter as entered by the user or one of the
@@ -260,41 +222,10 @@ public:
      *
      * @see setFilter()
      * @see filterChanged()
+     *
+     * @since 6.0
      */
-    QString currentFilter() const;
-
-    /**
-     * Returns the MIME type for the desired output format.
-     *
-     * This is only valid if setFilterMimeType() has been called
-     * previously.
-     *
-     * @see setFilterMimeType()
-     */
-    QMimeType currentFilterMimeType();
-
-    /**
-     * Sets the filter up to specify the output type.
-     *
-     * @param types a list of MIME types that can be used as output format
-     * @param defaultType the default MIME type to use as output format, if any.
-     * If @p defaultType is set, it will be set as the current item.
-     * Otherwise, a first item showing all the MIME types will be created.
-     * Typically, @p defaultType should be empty for loading and set for saving.
-     *
-     * Do not use in conjunction with setFilter()
-     */
-    void setMimeFilter(const QStringList &types, const QString &defaultType = QString());
-
-    /**
-     * The MIME type for the desired output format.
-     *
-     * This is only valid if setMimeFilter() has been called
-     * previously.
-     *
-     * @see setMimeFilter()
-     */
-    QString currentMimeFilter() const;
+    KFileFilter currentFilter() const;
 
     /**
      *  Clears any MIME type or name filter. Does not reload the directory.
@@ -352,16 +283,6 @@ public:
      */
     void setLocationLabel(const QString &text);
 
-#if KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(5, 66)
-    /**
-     * Returns a pointer to the toolbar.
-     * @deprecated since 5.66 due to no known users and leaking KXMLGui into the API.
-     *
-     */
-    KIOFILEWIDGETS_DEPRECATED_VERSION(5, 66, "No known user")
-    KToolBar *toolBar() const;
-#endif
-
     /**
      * @returns a pointer to the OK-Button in the filedialog.
      * Note that the button is hidden and unconnected when using KFileWidget alone;
@@ -386,12 +307,6 @@ public:
      */
     KFileFilterCombo *filterWidget() const;
 
-    /**
-     * @returns a pointer to the action collection, holding all the used
-     * KActions.
-     */
-    KActionCollection *actionCollection() const;
-
     /**
      * This method implements the logic to determine the user's default directory
      * to be listed. E.g. the documents directory, home directory or a recently
@@ -428,7 +343,6 @@ public:
      *         KDirSelectDialog).
      *
      * @see KFileWidget::KFileWidget()
-     * @since 4.3
      */
     static QUrl getStartUrl(const QUrl &startDir, QString &recentDirClass, QString &fileName);
 
@@ -442,7 +356,7 @@ public:
      * Set a custom widget that should be added to the file dialog.
      * @param widget A widget, or a widget of widgets, for displaying custom
      *               data in the file widget. This can be used, for example, to
-     *               display a check box with the caption "Open as read-only".
+     *               display a check box with the title "Open as read-only".
      *               When creating this widget, you don't need to specify a parent,
      *               since the widget's parent will be set automatically by KFileWidget.
      */
@@ -465,7 +379,6 @@ public:
      * when an overwrite might occur.
      *
      * @param enable Set this to true to enable checking.
-     * @since 4.2
      */
     void setConfirmOverwrite(bool enable);
 
@@ -473,7 +386,6 @@ public:
      * Forces the inline previews to be shown or hidden, depending on @p show.
      *
      * @param show Whether to show inline previews or not.
-     * @since 4.2
      */
     void setInlinePreviewShown(bool show);
 
@@ -570,8 +482,10 @@ Q_SIGNALS:
      *
      * @see setFilter()
      * @see currentFilter()
+     *
+     * @since 6.0
      */
-    void filterChanged(const QString &filter);
+    void filterChanged(const KFileFilter &filter);
 
     /**
      * Emitted by slotOk() (directly or asynchronously) once everything has
@@ -582,14 +496,12 @@ Q_SIGNALS:
 public:
     /**
      * @returns the KDirOperator used to navigate the filesystem
-     * @since 4.3
      */
     KDirOperator *dirOperator();
 
     /**
      * reads the configuration for this widget from the given config group
      * @param group the KConfigGroup to read from
-     * @since 4.4
      */
     void readConfig(KConfigGroup &group);
 
