@@ -10,26 +10,20 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#include "kuriikwsfiltereng.h"
+#include "kuriikwsfiltereng_p.h"
 #include "searchprovider.h"
 
 #include <KConfig>
 #include <KConfigGroup>
 #include <kprotocolinfo.h>
 
+#include <QDBusConnection>
 #include <QLoggingCategory>
 #include <QRegularExpression>
-#include <QTextCodec>
+#include <QStringEncoder>
 
-namespace
-{
 Q_LOGGING_CATEGORY(category, "kf.kio.urifilters.ikws", QtWarningMsg)
-}
-
-static void kuriikws_debug(const QString &n, const QString &v)
-{
-    qCDebug(category) << n << " = '" << v << "'";
-}
+using namespace KIO;
 
 /**
  * IMPORTANT: If you change anything here, make sure kiowidgets-kurifiltertest-{colon,space}-separator
@@ -38,12 +32,15 @@ static void kuriikws_debug(const QString &n, const QString &v)
 
 KURISearchFilterEngine::KURISearchFilterEngine()
 {
-    loadConfig();
+    configure();
+    // Only after initial load, we would want to reparse the files on config changes.
+    // When the registry is constructed, it automatically loads the searchproviders
+    m_reloadRegistry = true;
+    QDBusConnection::sessionBus()
+        .connect(QString(), QStringLiteral("/"), QStringLiteral("org.kde.KUriFilterPlugin"), QStringLiteral("configure"), this, SLOT(configure()));
 }
 
-KURISearchFilterEngine::~KURISearchFilterEngine()
-{
-}
+KURISearchFilterEngine::~KURISearchFilterEngine() = default;
 
 // static
 QStringList KURISearchFilterEngine::defaultSearchProviders()
@@ -62,7 +59,7 @@ SearchProvider *KURISearchFilterEngine::webShortcutQuery(const QString &typedStr
         SearchProvider *provider = nullptr;
         // If the key contains a : an assertion in the isKnownProtocol method would fail. This can be
         // the case if the delimiter is switched to space, see kiowidgets_space_separator_test
-        if (!key.isEmpty() && (key.contains(QLatin1Char(':')) || !KProtocolInfo::isKnownProtocol(key))) {
+        if (!key.isEmpty() && (key.contains(QLatin1Char(':')) || !KProtocolInfo::isKnownProtocol(key, false))) {
             provider = m_registry.findByKey(key);
             if (provider) {
                 if (!m_bUseOnlyPreferredWebShortcuts || m_preferredWebShortcuts.contains(provider->desktopEntryName())) {
@@ -123,7 +120,7 @@ SearchProvider *KURISearchFilterEngine::autoWebSearchQuery(const QString &typedS
         // Make sure we ignore supported protocols, e.g. "smb:", "http:"
         const int pos = typedString.indexOf(QLatin1Char(':'));
 
-        if (pos == -1 || !KProtocolInfo::isKnownProtocol(typedString.left(pos))) {
+        if (pos == -1 || !KProtocolInfo::isKnownProtocol(typedString.left(pos), false)) {
             provider = m_registry.findByDesktopName(defaultSearchProvider);
         }
     }
@@ -151,11 +148,10 @@ QStringList KURISearchFilterEngine::favoriteEngineList() const
     return m_preferredWebShortcuts;
 }
 
-Q_GLOBAL_STATIC(KURISearchFilterEngine, sSelfPtr)
-
 KURISearchFilterEngine *KURISearchFilterEngine::self()
 {
-    return sSelfPtr;
+    static KURISearchFilterEngine self;
+    return &self;
 }
 
 QStringList KURISearchFilterEngine::modifySubstitutionMap(SubstMap &map, const QString &query) const
@@ -165,7 +161,7 @@ QStringList KURISearchFilterEngine::modifySubstitutionMap(SubstMap &map, const Q
 
     // Do some pre-encoding, before we can start the work:
     {
-        const QRegularExpression qsexpr(QStringLiteral("\\\"[^\\\"]*\\\""));
+        const static QRegularExpression qsexpr(QStringLiteral("\\\"[^\\\"]*\\\""));
         // Temporarily substitute spaces in quoted strings (" " -> "%20")
         // Needed to split user query into StringList correctly.
         int start = 0;
@@ -190,7 +186,6 @@ QStringList KURISearchFilterEngine::modifySubstitutionMap(SubstMap &map, const Q
     for (int i = 0; i <= l.count(); i++) {
         int pos = 0;
         QString v;
-        QString nr = QString::number(i);
 
         // Add whole user query (\{0}) to substitution map:
         if (i == 0) {
@@ -203,7 +198,6 @@ QStringList KURISearchFilterEngine::modifySubstitutionMap(SubstMap &map, const Q
 
         // Insert partial queries (referenced by \1 ... \n) to map:
         map.insert(QString::number(i), v);
-        kuriikws_debug(QLatin1String("  map['") + nr + QLatin1String("']"), map[nr]);
 
         // Insert named references (referenced by \name) to map:
         if ((i > 0) && (pos = v.indexOf(QLatin1Char('='))) > 0) {
@@ -213,41 +207,28 @@ QStringList KURISearchFilterEngine::modifySubstitutionMap(SubstMap &map, const Q
             // Back-substitute references contained in references (e.g. '\refname' substitutes to 'thisquery=\0')
             s.replace(QLatin1String("%5C"), QLatin1String("\\"));
             map.insert(k, s);
-            kuriikws_debug(QLatin1String("  map['") + k + QLatin1String("']"), map[k]);
         }
     }
 
     return l;
 }
 
-static QString encodeString(const QString &s, QTextCodec *codec)
+static QString encodeString(const QString &s, QStringEncoder &codec)
 {
     // we encode all characters, including the space character BUG: 304276
-    QByteArray encoded = codec->fromUnicode(s).toPercentEncoding();
+    QByteArray encoded = QByteArray(codec.encode(s)).toPercentEncoding();
     return QString::fromUtf8(encoded);
 }
 
-QString KURISearchFilterEngine::substituteQuery(const QString &url, SubstMap &map, const QString &userquery, QTextCodec *codec) const
+QString KURISearchFilterEngine::substituteQuery(const QString &url, SubstMap &map, const QString &userquery, QStringEncoder &codec) const
 {
     QString newurl = url;
     QStringList ql = modifySubstitutionMap(map, userquery);
     const int count = ql.count();
 
-    // Check, if old style '\1' is found and replace it with \{@} (compatibility mode):
-    {
-        int pos = -1;
-        if ((pos = newurl.indexOf(QLatin1String("\\1"))) >= 0) {
-            qCWarning(category) << "WARNING: Using compatibility mode for newurl='" << newurl
-                                << "'. Please replace old style '\\1' with new style '\\{0}' "
-                                   "in the query definition.\n";
-            newurl.replace(pos, 2, QStringLiteral("\\{@}"));
-        }
-    }
-
-    qCDebug(category) << "Substitute references:\n";
     // Substitute references (\{ref1,ref2,...}) with values from user query:
     {
-        const QRegularExpression reflistRe(QStringLiteral("\\\\\\{([^\\}]+)\\}"));
+        const static QRegularExpression reflistRe(QStringLiteral("\\\\\\{([^\\}]+)\\}"));
         // Substitute reflists (\{ref1,ref2,...}):
         int start = 0;
         QRegularExpressionMatch match;
@@ -257,7 +238,6 @@ QString KURISearchFilterEngine::substituteQuery(const QString &url, SubstMap &ma
             // bool rest = false;
             QString v;
             const QString rlstring = match.captured(1);
-            kuriikws_debug(QStringLiteral("  reference list"), rlstring);
 
             // \{@} gets a special treatment later
             if (rlstring == QLatin1String("@")) {
@@ -273,7 +253,7 @@ QString KURISearchFilterEngine::substituteQuery(const QString &url, SubstMap &ma
                     break;
                 }
 
-                const QRegularExpression rangeRe(QStringLiteral("([0-9]*)\\-([0-9]*)"));
+                const static QRegularExpression rangeRe(QStringLiteral("([0-9]*)\\-([0-9]*)"));
                 const QRegularExpressionMatch rangeMatch = rangeRe.match(rlitem);
                 // Substitute a range of keywords
                 if (rangeMatch.hasMatch()) {
@@ -299,19 +279,15 @@ QString KURISearchFilterEngine::substituteQuery(const QString &url, SubstMap &ma
                         found = true;
                     }
 
-                    kuriikws_debug(QStringLiteral("    range"),
-                                   QString::number(first) + QLatin1Char('-') + QString::number(last) + QLatin1String(" => '") + v + QLatin1Char('\''));
                     v = encodeString(v, codec);
                 } else if (rlitem.startsWith(QLatin1Char('\"')) && rlitem.endsWith(QLatin1Char('\"'))) {
                     // Use default string from query definition:
                     found = true;
                     QString s = rlitem.mid(1, rlitem.length() - 2);
                     v = encodeString(s, codec);
-                    kuriikws_debug(QStringLiteral("    default"), s);
                 } else if (map.contains(rlitem)) {
                     // Use value from substitution map:
                     found = true;
-                    kuriikws_debug(QLatin1String("    map['") + rlitem + QLatin1String("']"), map[rlitem]);
                     v = encodeString(map[rlitem], codec);
 
                     // Remove used value from ql (needed for \{@}):
@@ -340,7 +316,6 @@ QString KURISearchFilterEngine::substituteQuery(const QString &url, SubstMap &ma
                     v.replace(QLatin1Char('+'), QLatin1String("%2B"));
                 } else if (rlitem == QLatin1String("@")) {
                     v = QStringLiteral("\\@");
-                    kuriikws_debug(QStringLiteral("    v"), v);
                 }
             }
 
@@ -350,11 +325,8 @@ QString KURISearchFilterEngine::substituteQuery(const QString &url, SubstMap &ma
 
         // Special handling for \{@};
         {
-            kuriikws_debug(QStringLiteral("  newurl"), newurl);
             // Generate list of unmatched strings:
             QString v = ql.join(QLatin1Char(' ')).simplified();
-
-            kuriikws_debug(QStringLiteral("    rest"), v);
             v = encodeString(v, codec);
 
             // Substitute \{@} with list of unmatched query strings
@@ -384,29 +356,18 @@ QUrl KURISearchFilterEngine::formatResult(const QString &url,
         return QUrl();
     }
 
-    // Debug info of map:
-    if (!map.isEmpty()) {
-        qCDebug(category) << "Got non-empty substitution map:\n";
-        for (SubstMap::Iterator it = map.begin(); it != map.end(); ++it) {
-            kuriikws_debug(QLatin1String("    map['") + it.key() + QLatin1String("']"), it.value());
-        }
-    }
-
     // Create a codec for the desired encoding so that we can transcode the user's "url".
     QString cseta = cset1;
     if (cseta.isEmpty()) {
         cseta = QStringLiteral("UTF-8");
     }
 
-    QTextCodec *csetacodec = QTextCodec::codecForName(cseta.toLatin1());
-    if (!csetacodec) {
+    QStringEncoder csetacodec(cseta.toLatin1().constData());
+    if (!csetacodec.isValid()) {
         cseta = QStringLiteral("UTF-8");
-        csetacodec = QTextCodec::codecForName(cseta.toLatin1());
+        csetacodec = QStringEncoder(QStringEncoder::Utf8);
     }
 
-    kuriikws_debug(QStringLiteral("user query"), userquery);
-    kuriikws_debug(QStringLiteral("query definition"), url);
-
     // Add charset indicator for the query to substitution map:
     map.insert(QStringLiteral("ikw_charset"), cseta);
 
@@ -419,20 +380,18 @@ QUrl KURISearchFilterEngine::formatResult(const QString &url,
 
     QString newurl = substituteQuery(url, map, userquery, csetacodec);
 
-    kuriikws_debug(QStringLiteral("substituted query"), newurl);
-
     return QUrl(newurl, QUrl::StrictMode);
 }
 
-void KURISearchFilterEngine::loadConfig()
+void KURISearchFilterEngine::configure()
 {
     qCDebug(category) << "Keywords Engine: Loading config...";
 
     // Load the config.
     KConfig config(QString::fromUtf8(name()) + QLatin1String("rc"), KConfig::NoGlobals);
-    KConfigGroup group = config.group("General");
+    KConfigGroup group = config.group(QStringLiteral("General"));
 
-    m_cKeywordDelimiter = QString(group.readEntry("KeywordDelimiter", ":")).at(0).toLatin1();
+    m_cKeywordDelimiter = group.readEntry("KeywordDelimiter", ":").at(0).toLatin1();
     m_bWebShortcutsEnabled = group.readEntry("EnableWebShortcuts", true);
     m_defaultWebShortcut = group.readEntry("DefaultWebShortcut", "duckduckgo");
     m_bUseOnlyPreferredWebShortcuts = group.readEntry("UsePreferredWebShortcutsOnly", false);
@@ -451,10 +410,14 @@ void KURISearchFilterEngine::loadConfig()
     qCDebug(category) << "Web Shortcuts Enabled: " << m_bWebShortcutsEnabled;
     qCDebug(category) << "Default Shortcut: " << m_defaultWebShortcut;
     qCDebug(category) << "Keyword Delimiter: " << m_cKeywordDelimiter;
-    m_registry.reload();
+    if (m_reloadRegistry) {
+        m_registry.reload();
+    }
 }
 
 SearchProviderRegistry *KURISearchFilterEngine::registry()
 {
     return &m_registry;
 }
+
+#include "moc_kuriikwsfiltereng_p.cpp"
