@@ -1,30 +1,19 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 1999,2000,2001 Carsten Pfeiffer <pfeiffer@kde.org>
-    Copyright (C) 2013           Teo Mrnjavac <teo@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999, 2000, 2001 Carsten Pfeiffer <pfeiffer@kde.org>
+    SPDX-FileCopyrightText: 2013 Teo Mrnjavac <teo@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2, as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "kurlrequester.h"
+#include "../utils_p.h"
 #include "kio_widgets_debug.h"
-#include "../pathhelpers_p.h"
 
-#include <kcombobox.h>
-#include <kdragwidgetdecorator.h>
-#include <klineedit.h>
-#include <klocalizedstring.h>
+#include <KComboBox>
+#include <KDragWidgetDecorator>
+#include <KLineEdit>
+#include <KLocalizedString>
 #include <kprotocolmanager.h>
 #include <kurlcompletion.h>
 
@@ -32,10 +21,10 @@
 #include <QApplication>
 #include <QDrag>
 #include <QEvent>
-#include <QKeySequence>
 #include <QHBoxLayout>
-#include <QMimeData>
+#include <QKeySequence>
 #include <QMenu>
+#include <QMimeData>
 
 class KUrlDragPushButton : public QPushButton
 {
@@ -46,7 +35,9 @@ public:
     {
         new DragDecorator(this);
     }
-    ~KUrlDragPushButton() override {}
+    ~KUrlDragPushButton() override
+    {
+    }
 
     void setURL(const QUrl &url)
     {
@@ -59,7 +50,10 @@ private:
     {
     public:
         explicit DragDecorator(KUrlDragPushButton *button)
-            : KDragWidgetDecoratorBase(button), m_button(button) {}
+            : KDragWidgetDecoratorBase(button)
+            , m_button(button)
+        {
+        }
 
     protected:
         QDrag *dragObject() override
@@ -82,16 +76,21 @@ private:
     QList<QUrl> m_urls;
 };
 
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 240)
+// regular expression string copied from QPlatformFileDialogHelper
+static const QString filterRegExpString = QStringLiteral("^(.*)\\(([a-zA-Z0-9_.,*? +;#\\-\\[\\]@\\{\\}/!<>\\$%&=^~:\\|]*)\\)$");
+#endif
+
 class Q_DECL_HIDDEN KUrlRequester::KUrlRequesterPrivate
 {
 public:
     explicit KUrlRequesterPrivate(KUrlRequester *parent)
-        : m_fileDialogModeWasDirAndFile(false),
-          m_parent(parent),
-          edit(nullptr),
-          combo(nullptr),
-          fileDialogMode(KFile::File | KFile::ExistingOnly | KFile::LocalOnly),
-          fileDialogAcceptMode(QFileDialog::AcceptOpen)
+        : m_fileDialogModeWasDirAndFile(false)
+        , m_parent(parent)
+        , edit(nullptr)
+        , combo(nullptr)
+        , fileDialogMode(KFile::File | KFile::ExistingOnly | KFile::LocalOnly)
+        , fileDialogAcceptMode(QFileDialog::AcceptOpen)
     {
     }
 
@@ -125,27 +124,20 @@ public:
     void connectSignals(KUrlRequester *receiver)
     {
         if (combo) {
-            connect(combo, &QComboBox::currentTextChanged,
-                    receiver, &KUrlRequester::textChanged);
-            connect(combo, &QComboBox::editTextChanged,
-                    receiver, &KUrlRequester::textEdited);
+            connect(combo, &QComboBox::currentTextChanged, receiver, &KUrlRequester::textChanged);
+            connect(combo, &QComboBox::editTextChanged, receiver, &KUrlRequester::textEdited);
 
-            connect(combo, QOverload<>::of(&KComboBox::returnPressed),
-                    receiver, QOverload<>::of(&KUrlRequester::returnPressed));
-            connect(combo, QOverload<const QString&>::of(&KComboBox::returnPressed),
-                    receiver, QOverload<const QString&>::of(&KUrlRequester::returnPressed));
+            connect(combo, &KComboBox::returnPressed, receiver, &KUrlRequester::returnPressed);
         } else if (edit) {
-            connect(edit, &QLineEdit::textChanged,
-                    receiver, &KUrlRequester::textChanged);
-            connect(edit, &QLineEdit::textEdited,
-                    receiver, &KUrlRequester::textEdited);
+            connect(edit, &QLineEdit::textChanged, receiver, &KUrlRequester::textChanged);
+            connect(edit, &QLineEdit::textEdited, receiver, &KUrlRequester::textEdited);
 
-            connect(edit, QOverload<>::of(&QLineEdit::returnPressed),
-                    receiver, QOverload<>::of(&KUrlRequester::returnPressed));
+            connect(edit, qOverload<>(&QLineEdit::returnPressed), receiver, [this]() {
+                m_parent->Q_EMIT returnPressed(QString{});
+            });
 
-            if (auto kline = qobject_cast<KLineEdit*>(edit)) {
-                connect(kline, QOverload<const QString&>::of(&KLineEdit::returnPressed),
-                        receiver, QOverload<const QString&>::of(&KUrlRequester::returnPressed));
+            if (auto kline = qobject_cast<KLineEdit *>(edit)) {
+                connect(kline, &KLineEdit::returnKeyPressed, receiver, &KUrlRequester::returnPressed);
             }
         }
     }
@@ -164,7 +156,6 @@ public:
         myCompletion->setDir(newStartDir);
     }
 
-
     QString text() const
     {
         return combo ? combo->currentText() : edit->text();
@@ -185,19 +176,20 @@ public:
         }
 
         QString enteredPath;
-        if (comp)
+        if (comp) {
             enteredPath = comp->replacedPath(txt);
-        else
+        } else {
             enteredPath = txt;
+        }
 
-        if (QDir::isAbsolutePath(enteredPath)) {
+        if (Utils::isAbsoluteLocalPath(enteredPath)) {
             return QUrl::fromLocalFile(enteredPath);
         }
 
         const QUrl enteredUrl = QUrl(enteredPath); // absolute or relative
         if (enteredUrl.isRelative() && !txt.isEmpty()) {
             QUrl finalUrl(m_startDir);
-            finalUrl.setPath(concatPaths(finalUrl.path(), enteredPath));
+            finalUrl.setPath(Utils::concatPaths(finalUrl.path(), enteredPath));
             return finalUrl;
         } else {
             return enteredUrl;
@@ -210,15 +202,12 @@ public:
         bool dirsOnly = false;
         if (m & KFile::Directory) {
             fileMode = QFileDialog::Directory;
-            if ((m & KFile::File) == 0 &&
-                    (m & KFile::Files) == 0) {
+            if ((m & KFile::File) == 0 && (m & KFile::Files) == 0) {
                 dirsOnly = true;
             }
-        } else if (m & KFile::Files &&
-                   m & KFile::ExistingOnly) {
+        } else if (m & KFile::Files && m & KFile::ExistingOnly) {
             fileMode = QFileDialog::ExistingFiles;
-        } else if (m & KFile::File &&
-                   m & KFile::ExistingOnly) {
+        } else if (m & KFile::File && m & KFile::ExistingOnly) {
             fileMode = QFileDialog::ExistingFile;
         } else {
             fileMode = QFileDialog::AnyFile;
@@ -229,25 +218,61 @@ public:
         dlg->setOption(QFileDialog::ShowDirsOnly, dirsOnly);
     }
 
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 240)
     // Converts from "*.foo *.bar|Comment" to "Comment (*.foo *.bar)"
     QStringList kToQFilters(const QString &filters) const
     {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        QStringList qFilters = filters.split(QLatin1Char('\n'), QString::SkipEmptyParts);
-#else
         QStringList qFilters = filters.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
-#endif
 
         for (QString &qFilter : qFilters) {
             int sep = qFilter.indexOf(QLatin1Char('|'));
-            const QStringRef globs = qFilter.leftRef(sep);
-            const QStringRef desc  = qFilter.midRef(sep + 1);
-            qFilter = desc + QLatin1String(" (") + globs + QLatin1Char(')');
+            if (sep != -1) {
+                const QStringView fView(qFilter);
+                const auto globs = fView.left(sep).trimmed();
+                const auto desc = fView.mid(sep + 1).trimmed();
+                qFilter = desc + QLatin1String(" (") + globs + QLatin1Char(')');
+            }
         }
 
         return qFilters;
     }
 
+    // Makes a list of filters from a normal filter string "Image Files (*.png *.jpg)"
+    static QString qToKFilter(const QStringList &filters)
+    {
+        const QRegularExpression regexp(filterRegExpString);
+        QStringList result;
+        for (const QString &filter : filters) {
+            QRegularExpressionMatch match;
+            filter.indexOf(regexp, 0, &match);
+            if (match.hasMatch()) {
+                result.append(match.capturedView(2).trimmed() + QLatin1Char('|') + match.capturedView(1).trimmed());
+            } else {
+                result.append(filter);
+            }
+        }
+        return result.join(QLatin1Char('\n'));
+    }
+
+    // Provides work-around for older Plasma Qt Platform Theme integration versions
+    // only processing filters with explicit names (bug 470893),
+    // use the filter expressions as name as fallback if no name is given
+    // TODO: find a way to test if the current theme is a broken Plasma one, otherwise skip
+    static QStringList ensureNamedFilter(const QStringList &filters)
+    {
+        QStringList namedFilters(filters);
+        const QRegularExpression regexp(filterRegExpString);
+        for (QString &filter : namedFilters) {
+            QRegularExpressionMatch match;
+            filter.indexOf(regexp, 0, &match);
+            if (!match.hasMatch()) {
+                filter = filter + QLatin1String(" (") + filter + QLatin1Char(')');
+            }
+        }
+        return namedFilters;
+    }
+#endif
+
     QUrl getDirFromFileDialog(const QUrl &openUrl) const
     {
         return QFileDialog::getExistingDirectoryUrl(m_parent, QString(), openUrl, QFileDialog::ShowDirsOnly);
@@ -255,7 +280,7 @@ public:
 
     void createFileDialog()
     {
-        //Creates the fileDialog if it doesn't exist yet
+        // Creates the fileDialog if it doesn't exist yet
         QFileDialog *dlg = m_parent->fileDialog();
 
         if (!url().isEmpty() && !url().isRelative()) {
@@ -270,7 +295,7 @@ public:
 
         dlg->setAcceptMode(fileDialogAcceptMode);
 
-        //Update the file dialog window modality
+        // Update the file dialog window modality
         if (dlg->windowModality() != fileDialogModality) {
             dlg->setWindowModality(fileDialogModality);
         }
@@ -283,19 +308,19 @@ public:
     }
 
     // slots
-    void _k_slotUpdateUrl();
-    void _k_slotOpenDialog();
-    void _k_slotFileDialogAccepted();
+    void slotUpdateUrl();
+    void slotOpenDialog();
+    void slotFileDialogAccepted();
 
     QUrl m_startDir;
     bool m_startDirCustomized;
     bool m_fileDialogModeWasDirAndFile;
-    KUrlRequester * const m_parent; // TODO: rename to 'q'
+    KUrlRequester *const m_parent; // TODO: rename to 'q'
     KLineEdit *edit;
     KComboBox *combo;
     KFile::Modes fileDialogMode;
     QFileDialog::AcceptMode fileDialogAcceptMode;
-    QString fileDialogFilter;
+    QStringList nameFilters;
     QStringList mimeTypeFilters;
     KEditListWidget::CustomEditor editor;
     KUrlDragPushButton *myButton;
@@ -305,7 +330,8 @@ public:
 };
 
 KUrlRequester::KUrlRequester(QWidget *editWidget, QWidget *parent)
-    : QWidget(parent), d(new KUrlRequesterPrivate(this))
+    : QWidget(parent)
+    , d(new KUrlRequesterPrivate(this))
 {
     // must have this as parent
     editWidget->setParent(this);
@@ -319,13 +345,15 @@ KUrlRequester::KUrlRequester(QWidget *editWidget, QWidget *parent)
 }
 
 KUrlRequester::KUrlRequester(QWidget *parent)
-    : QWidget(parent), d(new KUrlRequesterPrivate(this))
+    : QWidget(parent)
+    , d(new KUrlRequesterPrivate(this))
 {
     d->init();
 }
 
 KUrlRequester::KUrlRequester(const QUrl &url, QWidget *parent)
-    : QWidget(parent), d(new KUrlRequesterPrivate(this))
+    : QWidget(parent)
+    , d(new KUrlRequesterPrivate(this))
 {
     d->init();
     setUrl(url);
@@ -333,7 +361,8 @@ KUrlRequester::KUrlRequester(const QUrl &url, QWidget *parent)
 
 KUrlRequester::~KUrlRequester()
 {
-    delete d;
+    QWidget *widget = d->combo ? static_cast<QWidget *>(d->combo) : static_cast<QWidget *>(d->edit);
+    widget->removeEventFilter(this);
 }
 
 void KUrlRequester::KUrlRequesterPrivate::init()
@@ -359,7 +388,9 @@ void KUrlRequester::KUrlRequesterPrivate::init()
     myButton->setFixedSize(buttonSize, buttonSize);
     myButton->setToolTip(i18n("Open file dialog"));
 
-    connect(myButton, SIGNAL(pressed()), m_parent, SLOT(_k_slotUpdateUrl()));
+    connect(myButton, &KUrlDragPushButton::pressed, m_parent, [this]() {
+        slotUpdateUrl();
+    });
 
     widget->installEventFilter(m_parent);
     m_parent->setFocusProxy(widget);
@@ -367,7 +398,9 @@ void KUrlRequester::KUrlRequesterPrivate::init()
     topLayout->addWidget(myButton);
 
     connectSignals(m_parent);
-    connect(myButton, SIGNAL(clicked()), m_parent, SLOT(_k_slotOpenDialog()));
+    connect(myButton, &KUrlDragPushButton::clicked, m_parent, [this]() {
+        slotOpenDialog();
+    });
 
     m_startDir = QUrl::fromLocalFile(QDir::currentPath());
     m_startDirCustomized = false;
@@ -379,7 +412,9 @@ void KUrlRequester::KUrlRequesterPrivate::init()
 
     QAction *openAction = new QAction(m_parent);
     openAction->setShortcut(QKeySequence::Open);
-    m_parent->connect(openAction, SIGNAL(triggered(bool)), SLOT(_k_slotOpenDialog()));
+    m_parent->connect(openAction, &QAction::triggered, m_parent, [this]() {
+        slotOpenDialog();
+    });
 }
 
 void KUrlRequester::setUrl(const QUrl &url)
@@ -387,11 +422,6 @@ void KUrlRequester::setUrl(const QUrl &url)
     d->setText(url.toDisplayString(QUrl::PreferLocalFile));
 }
 
-void KUrlRequester::setPath(const QString &path)
-{
-    d->setText(path);
-}
-
 void KUrlRequester::setText(const QString &text)
 {
     d->setText(text);
@@ -429,23 +459,22 @@ QString KUrlRequester::text() const
     return d->text();
 }
 
-void KUrlRequester::KUrlRequesterPrivate::_k_slotOpenDialog()
+void KUrlRequester::KUrlRequesterPrivate::slotOpenDialog()
 {
-    if (myFileDialog)
+    if (myFileDialog) {
         if (myFileDialog->isVisible()) {
-            //The file dialog is already being shown, raise it and exit
+            // The file dialog is already being shown, raise it and exit
             myFileDialog->raise();
             myFileDialog->activateWindow();
             return;
         }
+    }
 
-    if (!m_fileDialogModeWasDirAndFile &&
-            (((fileDialogMode & KFile::Directory) && !(fileDialogMode & KFile::File)) ||
-             /* catch possible fileDialog()->setMode( KFile::Directory ) changes */
-             (myFileDialog && (myFileDialog->fileMode() == QFileDialog::Directory &&
-                               myFileDialog->testOption(QFileDialog::ShowDirsOnly))))) {
-        const QUrl openUrl = (!m_parent->url().isEmpty() && !m_parent->url().isRelative())
-                             ? m_parent->url() : m_startDir;
+    if (!m_fileDialogModeWasDirAndFile
+        && (((fileDialogMode & KFile::Directory) && !(fileDialogMode & KFile::File)) ||
+            /* catch possible fileDialog()->setMode( KFile::Directory ) changes */
+            (myFileDialog && (myFileDialog->fileMode() == QFileDialog::Directory && myFileDialog->testOption(QFileDialog::ShowDirsOnly))))) {
+        const QUrl openUrl = (!m_parent->url().isEmpty() && !m_parent->url().isRelative()) ? m_parent->url() : m_startDir;
 
         /* FIXME We need a new abstract interface for using KDirSelectDialog in a non-modal way */
 
@@ -458,10 +487,10 @@ void KUrlRequester::KUrlRequesterPrivate::_k_slotOpenDialog()
 
         if (newUrl.isValid()) {
             m_parent->setUrl(newUrl);
-            emit m_parent->urlSelected(url());
+            Q_EMIT m_parent->urlSelected(url());
         }
     } else {
-        emit m_parent->openFileDialog(m_parent);
+        Q_EMIT m_parent->openFileDialog(m_parent);
 
         if (((fileDialogMode & KFile::Directory) && (fileDialogMode & KFile::File)) || m_fileDialogModeWasDirAndFile) {
             QMenu *dirOrFileMenu = new QMenu();
@@ -493,7 +522,7 @@ void KUrlRequester::KUrlRequesterPrivate::_k_slotOpenDialog()
     }
 }
 
-void KUrlRequester::KUrlRequesterPrivate::_k_slotFileDialogAccepted()
+void KUrlRequester::KUrlRequesterPrivate::slotFileDialogAccepted()
 {
     if (!myFileDialog) {
         return;
@@ -502,7 +531,7 @@ void KUrlRequester::KUrlRequesterPrivate::_k_slotFileDialogAccepted()
     const QUrl newUrl = myFileDialog->selectedUrls().constFirst();
     if (newUrl.isValid()) {
         m_parent->setUrl(newUrl);
-        emit m_parent->urlSelected(url());
+        Q_EMIT m_parent->urlSelected(url());
         // remember url as defaultStartDir and update startdir for autocompletion
         if (newUrl.isLocalFile() && !m_startDirCustomized) {
             m_startDir = newUrl.adjusted(QUrl::RemoveFilename);
@@ -543,18 +572,57 @@ QFileDialog::AcceptMode KUrlRequester::acceptMode() const
     return d->fileDialogAcceptMode;
 }
 
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 240)
 void KUrlRequester::setFilter(const QString &filter)
 {
-    d->fileDialogFilter = filter;
+    d->nameFilters = d->kToQFilters(filter);
 
     if (d->myFileDialog) {
-        d->myFileDialog->setNameFilters(d->kToQFilters(d->fileDialogFilter));
+        d->myFileDialog->setNameFilters(d->ensureNamedFilter(d->nameFilters));
+    }
+}
+#endif
+
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 240)
+QString KUrlRequester::filter() const
+{
+    return d->qToKFilter(d->nameFilters);
+}
+#endif
+
+QStringList KUrlRequester::nameFilters() const
+{
+    return d->nameFilters;
+}
+
+void KUrlRequester::setNameFilters(const QStringList &filters)
+{
+    d->nameFilters = filters;
+
+    if (d->myFileDialog) {
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 240)
+        d->myFileDialog->setNameFilters(d->ensureNamedFilter(d->nameFilters));
+#else
+        d->myFileDialog->setNameFilters(d->nameFilters);
+#endif
     }
 }
 
-QString KUrlRequester::filter() const
+void KUrlRequester::setNameFilter(const QString &filter)
 {
-    return d->fileDialogFilter;
+    if (filter.isEmpty()) {
+        setNameFilters(QStringList());
+        return;
+    }
+
+    // by default use ";;" as separator
+    // if not present, support alternatively "\n" (matching QFileDialog behaviour)
+    // if also not present split() will simply return the string passed in
+    QString separator = QStringLiteral(";;");
+    if (!filter.contains(separator)) {
+        separator = QStringLiteral("\n");
+    }
+    setNameFilters(filter.split(separator));
 }
 
 void KUrlRequester::setMimeTypeFilters(const QStringList &mimeTypes)
@@ -574,9 +642,9 @@ QStringList KUrlRequester::mimeTypeFilters() const
 
 QFileDialog *KUrlRequester::fileDialog() const
 {
-    if (d->myFileDialog &&
-            (   (d->myFileDialog->fileMode() == QFileDialog::Directory && !(d->fileDialogMode & KFile::Directory))
-             || (d->myFileDialog->fileMode() != QFileDialog::Directory &&  (d->fileDialogMode & KFile::Directory)))) {
+    if (d->myFileDialog
+        && ((d->myFileDialog->fileMode() == QFileDialog::Directory && !(d->fileDialogMode & KFile::Directory))
+            || (d->myFileDialog->fileMode() != QFileDialog::Directory && (d->fileDialogMode & KFile::Directory)))) {
         delete d->myFileDialog;
         d->myFileDialog = nullptr;
     }
@@ -586,13 +654,19 @@ QFileDialog *KUrlRequester::fileDialog() const
         if (!d->mimeTypeFilters.isEmpty()) {
             d->myFileDialog->setMimeTypeFilters(d->mimeTypeFilters);
         } else {
-            d->myFileDialog->setNameFilters(d->kToQFilters(d->fileDialogFilter));
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 240)
+            d->myFileDialog->setNameFilters(d->ensureNamedFilter(d->nameFilters));
+#else
+            d->myFileDialog->setNameFilters(d->nameFilters);
+#endif
         }
 
         d->applyFileMode(d->myFileDialog, d->fileDialogMode, d->fileDialogAcceptMode);
 
         d->myFileDialog->setWindowModality(d->fileDialogModality);
-        connect(d->myFileDialog, SIGNAL(accepted()), SLOT(_k_slotFileDialogAccepted()));
+        connect(d->myFileDialog, &QFileDialog::accepted, this, [this]() {
+            d->slotFileDialogAccepted();
+        });
     }
 
     return d->myFileDialog;
@@ -613,7 +687,7 @@ KComboBox *KUrlRequester::comboBox() const
     return d->combo;
 }
 
-void KUrlRequester::KUrlRequesterPrivate::_k_slotUpdateUrl()
+void KUrlRequester::KUrlRequesterPrivate::slotUpdateUrl()
 {
     const QUrl visibleUrl = url();
     QUrl u = visibleUrl;
@@ -627,7 +701,7 @@ bool KUrlRequester::eventFilter(QObject *obj, QEvent *ev)
 {
     if ((d->edit == obj) || (d->combo == obj)) {
         if ((ev->type() == QEvent::FocusIn) || (ev->type() == QEvent::FocusOut))
-            // Forward focusin/focusout events to the urlrequester; needed by file form element in khtml
+        // Forward focusin/focusout events to the urlrequester; needed by file form element in khtml
         {
             QApplication::sendEvent(this, ev);
         }
@@ -645,11 +719,6 @@ KUrlCompletion *KUrlRequester::completionObject() const
     return d->myCompletion;
 }
 
-void KUrlRequester::setClickMessage(const QString &msg)
-{
-    setPlaceholderText(msg);
-}
-
 void KUrlRequester::setPlaceholderText(const QString &msg)
 {
     if (d->edit) {
@@ -657,11 +726,6 @@ void KUrlRequester::setPlaceholderText(const QString &msg)
     }
 }
 
-QString KUrlRequester::clickMessage() const
-{
-    return placeholderText();
-}
-
 QString KUrlRequester::placeholderText() const
 {
     if (d->edit) {
@@ -683,8 +747,7 @@ void KUrlRequester::setFileDialogModality(Qt::WindowModality modality)
 
 const KEditListWidget::CustomEditor &KUrlRequester::customEditor()
 {
-    setSizePolicy(QSizePolicy(QSizePolicy::Preferred,
-                              QSizePolicy::Fixed));
+    setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed));
 
     KLineEdit *edit = d->edit;
     if (!edit && d->combo) {
@@ -703,9 +766,10 @@ const KEditListWidget::CustomEditor &KUrlRequester::customEditor()
 }
 
 KUrlComboRequester::KUrlComboRequester(QWidget *parent)
-    : KUrlRequester(new KComboBox(false), parent), d(nullptr)
+    : KUrlRequester(new KComboBox(false), parent)
+    , d(nullptr)
 {
 }
 
-#include "moc_kurlrequester.cpp"
 #include "kurlrequester.moc"
+#include "moc_kurlrequester.cpp"
